#' Rdiagnosislist: A package for manipulating SNOMED CT diagnosis lists
#'
#' The Rdiagnosislist package makes it easy to load a SNOMED dictionary
#' into R and use the hierarchies to search for concepts and navigate
#' relations between concepts.
#'
#' @keywords internal 
"_PACKAGE"
